diff src/xfns.c @ 83442:db27bb9f0d2f

Cosmetic fixes in xfns.c. * src/xfns.c (Fx_close_connection, Fx_synchronize): Unify argument names with the rest of the DEFUNs. git-archimport-id: lorentey@elte.hu--2004/emacs--multi-tty--0--patch-482
author Karoly Lorentey <lorentey@elte.hu>
date Sun, 01 Jan 2006 17:11:05 +0000
parents 76396de7f50a
children 9b150bc96d33
line wrap: on
line diff
--- a/src/xfns.c	Sat Dec 31 07:31:23 2005 +0000
+++ b/src/xfns.c	Sun Jan 01 17:11:05 2006 +0000
@@ -4064,13 +4064,14 @@
 
 DEFUN ("x-close-connection", Fx_close_connection,
        Sx_close_connection, 1, 1, 0,
-       doc: /* Close the connection to DISPLAY's X server.
-For DISPLAY, specify either a frame or a display name (a string).
-If DISPLAY is nil, that stands for the selected frame's display.  */)
-     (display)
-     Lisp_Object display;
+       doc: /* Close the connection to TERMINAL's X server.
+For TERMINAL, specify a terminal id, a frame or a display name (a
+string).  If TERMINAL is nil, that stands for the selected frame's
+terminal.  */)
+     (terminal)
+     Lisp_Object terminal;
 {
-  struct x_display_info *dpyinfo = check_x_display_info (display);
+  struct x_display_info *dpyinfo = check_x_display_info (terminal);
 
   if (dpyinfo->reference_count > 0)
     error ("Display still has frames on it");
@@ -4099,13 +4100,13 @@
 Turning on synchronization prohibits the Xlib routines from buffering
 requests and seriously degrades performance, but makes debugging much
 easier.
-The optional second argument DISPLAY specifies which display to act on.
-DISPLAY should be either a frame or a display name (a string).
-If DISPLAY is omitted or nil, that stands for the selected frame's display.  */)
-     (on, display)
-    Lisp_Object display, on;
+The optional second argument TERMINAL specifies which display to act on.
+TERMINAL should be a terminal id, a frame or a display name (a string).
+If TERMINAL is omitted or nil, that stands for the selected frame's display.  */)
+     (on, terminal)
+    Lisp_Object terminal, on;
 {
-  struct x_display_info *dpyinfo = check_x_display_info (display);
+  struct x_display_info *dpyinfo = check_x_display_info (terminal);
 
   XSynchronize (dpyinfo->display, !EQ (on, Qnil));